%Runing and saving SIR trajectory

load ../Settings/ADS_SIR_init.mat params SIR_vars_init SIR_varexo_init SIR_epi_init;

p.alpha=params.alphav; % transmision rate
p.gamma=params.gammav; % recovery rate

p.beta=params.betav; % asymptomatic transition rate
p.epsilon=params.epsilonv; % immunity (return to susceptible)

p.MaxTime=150; % time horizon of the simulation
p.dt=1; % step size

%%% main iteration %%%

% Susceptible-Infected-Recovered (SIR)
p.InitCond_SIR=[SIR_epi_init.S SIR_epi_init.Itilde SIR_epi_init.Rtilde]; % initial conditions (S,I,R)
options45_SIR=odeset('RelTol',1e-4,'NonNegative',1:3); % sets acceptable error for ODE solver

% matrices to store the data
T=zeros((p.MaxTime/p.dt),1);
Y_SIR_eu=zeros((p.MaxTime/p.dt),3);
Y_SIR_eu(1,:)=p.InitCond_SIR;

% 1st-order Euler approximation
for i=2:p.MaxTime/p.dt
    
    T(i) = T(i-1)+p.dt; % time vector    
    
    Y_SIR_eu(i,1) = Y_SIR_eu(i-1,1) + p.dt.*( -p.alpha.*Y_SIR_eu(i-1,1).*Y_SIR_eu(i-1,2)+p.epsilon.*Y_SIR_eu(i-1,3) ); % susceptible
    Y_SIR_eu(i,2) = Y_SIR_eu(i-1,2) + p.dt.*( p.alpha.*Y_SIR_eu(i-1,1).*Y_SIR_eu(i-1,2) - p.gamma.*Y_SIR_eu(i-1,2) ); % asymptomatic
    Y_SIR_eu(i,3) = Y_SIR_eu(i-1,3) + p.dt.*( p.gamma.*Y_SIR_eu(i-1,2)-p.epsilon.*Y_SIR_eu(i-1,3)); % recovered
    
end
sol_SIR_eu = [Y_SIR_eu(end,1) Y_SIR_eu(end,2) Y_SIR_eu(end,3)];

%{
f11=figure(1);
hold on
plot(T,Y_SIR_eu(:,1),'color','[0 0 0]');
plot(T,Y_SIR_eu(:,2),'color','[1 0 0]');
plot(T,Y_SIR_eu(:,3),'color','[0 0 1]');
legend({'susceptible','infected','recovered'})
xlim([0 p.MaxTime]);% ylim([0 1000]);
xlabel('time');ylabel('number of individuals');
hold off
%}

[t,y_SIR]=ode45(@(t,x) SIR_ode(x,p),[0 p.MaxTime],p.InitCond_SIR,options45_SIR); % Runge-Kutta (3rd-order ODE solver)
%disp(strcat( 'Equilibrium solutions (SIR): ',num2str(y_SIR(end,1)),' (S*)  ',num2str(y_SIR(end,2)),' (I*)  ',num2str(y_SIR(end,3)),' (R*)' ))
sol_SIR = [y_SIR(end,1) y_SIR(end,2) y_SIR(end,3)];

%{
f12=figure(2);
%set(f1,'Visible', 'off');
hold on
plot(t,y_SIR(:,1),'color','[0 0 0]');plot(t,y_SIR(:,2),'color','[1 0 0]');plot(t,y_SIR(:,3),'color','[0 0 1]');
legend({'susceptible','infected','recovered'})
xlim([0 p.MaxTime]);% ylim([0 1000]);
xlabel('time');ylabel('number of individuals');
hold off
savefig('SIR.fig')
%}

save ../Settings/SIR.mat T Y_SIR_eu sol_SIR_eu;       

