
%Runing epidemic codes and saving the trajectories 
        
% model parameters (SIR: 0.4/0.1)
load ../Settings/ADS_SIR_init.mat params SIR_vars_init SIR_varexo_init;
load ../Settings/ADS_SIS_init.mat params SIS_vars_init SIS_varexo_init;
load ../Settings/ADS_SAIR_init.mat params SAIR_vars_init SAIR_varexo_init;
load ../Settings/ADS_SIRS_init.mat params SIRS_vars_init SIRS_varexo_init;

p.alpha=params.alphav; % transmision rate
p.gamma=params.gammav; % recovery rate

p.beta=params.betav; % asymptomatic transition rate
p.epsilon=params.epsilonv; % immunity (return to susceptible)

p.MaxTime=150; % time horizon of the simulation


%%% main iteration %%%

% Susceptible-Infected-Recovered (SIR)

p.InitCond_SIR=[SIR_vars_init.S SIR_varexo_init.Itilde SIR_vars_init.Rtilde]; % initial conditions (S,I,R)
options45_SIR=odeset('RelTol',1e-4,'NonNegative',1:3); % sets acceptable error for ODE solver

[t,y_SIR]=ode45(@(t,x) SIR_ode(x,p),[0 p.MaxTime],p.InitCond_SIR,options45_SIR); % Runge-Kutta (3rd-order ODE solver)
%disp(strcat( 'Equilibrium solutions (SIR): ',num2str(y_SIR(end,1)),' (S*)  ',num2str(y_SIR(end,2)),' (I*)  ',num2str(y_SIR(end,3)),' (R*)' ))
sol_SIR = [y_SIR(end,1) y_SIR(end,2) y_SIR(end,3)];

set(0,'DefaultFigureVisible','off');

figure(1)
hold on
plot(t,y_SIR(:,1),'color','[0 0 0]');plot(t,y_SIR(:,2),'color','[1 0 0]');plot(t,y_SIR(:,3),'color','[0 0 1]');
legend({'susceptible','infected','recovered'})
xlim([0 p.MaxTime]);% ylim([0 1000]);
xlabel('time');ylabel('number of individuals');
hold off
savefig('SIR.fig')


% Susceptible-Infected-Susceptible (SIS)
p.InitCond_SIS=[SIS_vars_init.S SIS_varexo_init.Itilde]; % initial conditions (S,I)
options45_SIS=odeset('RelTol',1e-4,'NonNegative',1:2); % sets acceptable error for ODE solver

[ts,y_SIS]=ode45(@(t,x) SIS_ode(x,p),[0 p.MaxTime],p.InitCond_SIS,options45_SIS); % Runge-Kutta (3rd-order ODE solver)
%disp(strcat( 'Equilibrium (SIS): ',num2str(y_SIS(end,1)),' (S*)  ',num2str(y_SIS(end,2)),' (I*)' ))
sol_SIS = [y_SIS(end,1) y_SIS(end,2)];

figure(2)
hold on
plot(ts,y_SIS(:,1),'color','[0 0 0]');plot(ts,y_SIS(:,2),'color','[1 0 0]');
legend({'susceptible','infected'})
xlim([0 p.MaxTime]);% ylim([0 1000]);
xlabel('time');ylabel('number of individuals');
hold off
savefig('SIS.fig')



% Susceptible-Asymptomatic-Infected-Recovered (SAIR)
p.InitCond_SAIR=[SAIR_vars_init.S SAIR_vars_init.Atilde SAIR_varexo_init.Itilde SAIR_vars_init.Rtilde]; % initial conditions (S,A,I,R)
options45_SAIR=odeset('RelTol',1e-4,'NonNegative',1:4); % sets acceptable error for ODE solver

[tt,y_SAIR]=ode45(@(t,x) SAIR_ode(x,p),[0 p.MaxTime],p.InitCond_SAIR,options45_SAIR); % Runge-Kutta (3rd-order ODE solver)
%disp(strcat( 'Equilibrium (SAIR): ',num2str(y_SAIR(end,1)),' (S*)  ',num2str(y_SAIR(end,2)),' (A*)  ',num2str(y_SAIR(end,3)),' (I*)  ',num2str(y_SAIR(end,4)),' (R*)' ))
sol_SAIR = [y_SAIR(end,1) y_SAIR(end,2) y_SAIR(end,3) y_SAIR(end,4)];

figure(3)
hold on
plot(tt,y_SAIR(:,1),'color','[0 0 0]');plot(tt,y_SAIR(:,2),'color','[0.5 0 0.5]');plot(tt,y_SAIR(:,3),'color','[1 0 0]');plot(tt,y_SAIR(:,4),'color','[0 0 1]');
legend({'susceptible','asymptomatic','infected','recovered'})
xlim([0 p.MaxTime]);% ylim([0 1000]);
xlabel('time');ylabel('number of individuals');
hold off
savefig('SAIR.fig')


% Susceptible-Infected-Recovered-Susceptible (SIRS)
p.InitCond_SIRS=[SIRS_vars_init.S SIRS_varexo_init.Itilde SIRS_vars_init.Rtilde]; % initial conditions (S,I,R)
options45_SIRS=odeset('RelTol',1e-4,'NonNegative',1:3); % sets acceptable error for ODE solver

[tz,y_SIRS]=ode45(@(t,x) SIRS_ode(x,p),[0 p.MaxTime],p.InitCond_SIRS,options45_SIRS); % Runge-Kutta (3rd-order ODE solver)
%disp(strcat( 'Equilibrium solutions (SIRS): ',num2str(y_SIRS(end,1)),' (S*)  ',num2str(y_SIRS(end,2)),' (I*)  ',num2str(y_SIRS(end,3)),' (R*)' ))
sol_SIRS = [y_SIRS(end,1) y_SIRS(end,2) y_SIRS(end,3)];

figure(4)
hold on
plot(tz,y_SIRS(:,1),'color','[0 0 0]');plot(tz,y_SIRS(:,2),'color','[1 0 0]');plot(tz,y_SIRS(:,3),'color','[0 0 1]');
legend({'susceptible','infected','recovered'})
xlim([0 p.MaxTime]);% ylim([0 1000]);
xlabel('time');ylabel('number of individuals');
hold off
savefig('SIRS.fig')


save ../Settings/SIR.mat t y_SIR sol_SIR;       
save ../Settings/SIS.mat ts y_SIS sol_SIS;     
save ../Settings/SAIR.mat tt y_SAIR sol_SAIR;     
save ../Settings/SIRS.mat tz y_SIRS sol_SIRS;     

